"use strict";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.renderBadge = renderBadge;
exports.renderBadges = renderBadges;
exports.badges = void 0;

var badges = _interopRequireWildcard(require("./badges.js"));

exports.badges = badges;

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

// Import

/**
 * Render a specified badge with the appropriate wrapping (div if block badge, span if inline badge)
 * @method renderBadge
 * @param badgeName The name of the badge to render
 * @param config The configuration to pass to the badge render method
 * @return The rendered badge
 */
function renderBadge(badgeName) {
  var config = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if (badgeName === '---') {
    return '<br class="badge-separator" />';
  } // Fetch
  // @ts-ignore


  var badgeMethod = badges[badgeName]; // Send the badge value and options to the render method

  var badgeResult = badgeMethod(config).trim();
  if (!badgeResult) return ''; // We have a result, so let's wrap it

  var elementName = badgeMethod.badgeInline === false ? 'div' : 'span';
  var wrappedResult = "<".concat(elementName, " class=\"badge-").concat(badgeName, "\">").concat(badgeResult, "</").concat(elementName, ">"); // Done

  return wrappedResult;
}

/**
 * Render specified badges with wrapping
 * @param list The list of badge names to render
 * @param config The configuration to render the badge with
 * @param options An object that defaults to `{filterCategory: false, filterScripts: false}`
 * @return The rendered badges
 */
function renderBadges(list) {
  var config = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  var options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {
    filterCategory: false,
    filterScripts: true
  };
  // Prepare
  var results = []; // Render the badges

  list.forEach(function (badgeName) {
    var badgeConfig = config; // Custom Config?

    if (Array.isArray(badgeName)) {
      badgeConfig = badgeName[1];
      badgeName = badgeName[0];
    } // Seperator?


    if (badgeName === '---') {
      // Do not render seperators if we only wanted a single category
      if (options.filterCategory) return;
    } // Exists?
    else {
        // @ts-ignore
        var badge = badges[badgeName];

        if (badge) {
          // Category?
          if (options.filterCategory && options.filterCategory !== badge.badgeCategory) return; // Script?

          if (options.filterScripts && badge.badgeScript) return;
        } // Doesn't exist
        else {
            throw new Error("the badge ".concat(badgeName, " does not exist"));
          }
      } // Render


    var badgeResult = renderBadge(badgeName, badgeConfig).trim();
    if (!badgeResult) return; // Rendered successfully, add the result

    results.push(badgeResult);
  }); // Return

  return results.join('\n');
}